@@ -70,6 +70,7 @@ __all__ = (
     "WebhookBuildTypeType",
     "WebhookFilterTypeType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -439,10 +440,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -450,3 +453,17 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "describe_code_coverages",
+    "describe_test_cases",
+    "list_build_batches",
+    "list_build_batches_for_project",
+    "list_builds",
+    "list_builds_for_project",
+    "list_projects",
+    "list_report_groups",
+    "list_reports",
+    "list_reports_for_report_group",
+    "list_shared_projects",
+    "list_shared_report_groups",
+]
