@@ -99,7 +99,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class DescribeCodeCoveragesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describecodecoveragespaginator)
     """
 
@@ -107,21 +107,21 @@ class DescribeCodeCoveragesPaginator(Boto3Paginator):
         self,
         *,
         reportArn: str,
-        sortOrder: SortOrderTypeType = None,
-        sortBy: ReportCodeCoverageSortByTypeType = None,
-        minLineCoveragePercentage: float = None,
-        maxLineCoveragePercentage: float = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        sortOrder: SortOrderTypeType = ...,
+        sortBy: ReportCodeCoverageSortByTypeType = ...,
+        minLineCoveragePercentage: float = ...,
+        maxLineCoveragePercentage: float = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeCodeCoveragesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.DescribeCodeCoverages.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describecodecoveragespaginator)
         """
 
 
 class DescribeTestCasesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describetestcasespaginator)
     """
 
@@ -129,75 +129,72 @@ class DescribeTestCasesPaginator(Boto3Paginator):
         self,
         *,
         reportArn: str,
-        filter: "TestCaseFilterTypeDef" = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        filter: "TestCaseFilterTypeDef" = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeTestCasesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.DescribeTestCases.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#describetestcasespaginator)
         """
 
 
 class ListBuildBatchesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchespaginator)
     """
 
     def paginate(
         self,
         *,
-        filter: "BuildBatchFilterTypeDef" = None,
-        sortOrder: SortOrderTypeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        filter: "BuildBatchFilterTypeDef" = ...,
+        sortOrder: SortOrderTypeType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListBuildBatchesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatches.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchespaginator)
         """
 
 
 class ListBuildBatchesForProjectPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchesforprojectpaginator)
     """
 
     def paginate(
         self,
         *,
-        projectName: str = None,
-        filter: "BuildBatchFilterTypeDef" = None,
-        sortOrder: SortOrderTypeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        projectName: str = ...,
+        filter: "BuildBatchFilterTypeDef" = ...,
+        sortOrder: SortOrderTypeType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListBuildBatchesForProjectOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildBatchesForProject.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildbatchesforprojectpaginator)
         """
 
 
 class ListBuildsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildspaginator)
     """
 
     def paginate(
-        self,
-        *,
-        sortOrder: SortOrderTypeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, sortOrder: SortOrderTypeType = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListBuildsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildspaginator)
         """
 
 
 class ListBuildsForProjectPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildsforprojectpaginator)
     """
 
@@ -205,75 +202,75 @@ class ListBuildsForProjectPaginator(Boto3Paginator):
         self,
         *,
         projectName: str,
-        sortOrder: SortOrderTypeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        sortOrder: SortOrderTypeType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListBuildsForProjectOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listbuildsforprojectpaginator)
         """
 
 
 class ListProjectsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listprojectspaginator)
     """
 
     def paginate(
         self,
         *,
-        sortBy: ProjectSortByTypeType = None,
-        sortOrder: SortOrderTypeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        sortBy: ProjectSortByTypeType = ...,
+        sortOrder: SortOrderTypeType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListProjectsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listprojectspaginator)
         """
 
 
 class ListReportGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportgroupspaginator)
     """
 
     def paginate(
         self,
         *,
-        sortOrder: SortOrderTypeType = None,
-        sortBy: ReportGroupSortByTypeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        sortOrder: SortOrderTypeType = ...,
+        sortBy: ReportGroupSortByTypeType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListReportGroupsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListReportGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportgroupspaginator)
         """
 
 
 class ListReportsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListReports)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportspaginator)
     """
 
     def paginate(
         self,
         *,
-        sortOrder: SortOrderTypeType = None,
-        filter: "ReportFilterTypeDef" = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        sortOrder: SortOrderTypeType = ...,
+        filter: "ReportFilterTypeDef" = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListReportsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListReports.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListReports.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportspaginator)
         """
 
 
 class ListReportsForReportGroupPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportsforreportgrouppaginator)
     """
 
@@ -281,49 +278,49 @@ class ListReportsForReportGroupPaginator(Boto3Paginator):
         self,
         *,
         reportGroupArn: str,
-        sortOrder: SortOrderTypeType = None,
-        filter: "ReportFilterTypeDef" = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        sortOrder: SortOrderTypeType = ...,
+        filter: "ReportFilterTypeDef" = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListReportsForReportGroupOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListReportsForReportGroup.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listreportsforreportgrouppaginator)
         """
 
 
 class ListSharedProjectsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedprojectspaginator)
     """
 
     def paginate(
         self,
         *,
-        sortBy: SharedResourceSortByTypeType = None,
-        sortOrder: SortOrderTypeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        sortBy: SharedResourceSortByTypeType = ...,
+        sortOrder: SortOrderTypeType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSharedProjectsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedProjects.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedprojectspaginator)
         """
 
 
 class ListSharedReportGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedreportgroupspaginator)
     """
 
     def paginate(
         self,
         *,
-        sortOrder: SortOrderTypeType = None,
-        sortBy: SharedResourceSortByTypeType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        sortOrder: SortOrderTypeType = ...,
+        sortBy: SharedResourceSortByTypeType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSharedReportGroupsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/codebuild.html#CodeBuild.Paginator.ListSharedReportGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codebuild/paginators.html#listsharedreportgroupspaginator)
         """
